@@ -821,6 +821,8 @@ class VariableClBuilderPkgdir(Variable):
     """
 
     def fallback(self):
+        a = self.Get('cl_builder_base_path')
+        b = self.Get('cl_builder_id_path')
         return path.join(self.Get('cl_builder_base_path'),
                          self.Get('cl_builder_id_path'))
 
